# Plot Types

Statistical visualizations with a unified interface. All plots support dark/light themes, grayscale optimization, and publication-quality output.

```{toctree}
:maxdepth: 1

line
scatter
bar
histogram
box
heatmap
cdf
```

For detailed parameter documentation, see the {doc}`API Reference <../../api/index>`.

## Quick Reference

| Plot Type | Best For | Essential Parameters |
|-----------|----------|---------------------|
| [Line](line.md) | Time series, trends | `x`, `y`, `color` |
| [Scatter](scatter.md) | Relationships, correlations | `x`, `y`, `color`, `size` |
| [Bar](bar.md) | Categorical comparisons | `x`, `y`, `color` |
| [Histogram](histogram.md) | Distributions | `x`, `color` |
| [Box](box.md) | Statistical summaries | `x`, `y`, `color` |
| [Heatmap](heatmap.md) | 2D data, correlations | `data` |
| [CDF](cdf.md) | Cumulative distributions | `x`, `color` |

Each plot guide includes examples, parameter details, and best practices. Start with the plot type that matches your data and visualization goals.